#
# spec file for package fwupd-efi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


%if %{undefined sbat_distro}
%if 0%{?is_opensuse}
%define sbat_distro opensuse
%define sbat_distro_summary The openSUSE Project
%else
%define sbat_distro sle
%define sbat_distro_summary SUSE Linux Enterprise
%endif
%define sbat_distro_url mailto:security@suse.de
%endif
Name:           fwupd-efi
Version:        1.7
Release:        1.1
Summary:        Firmware update EFI binaries
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Management
URL:            https://github.com/fwupd/fwupd-efi
Source0:        https://github.com/fwupd/fwupd-efi/archive/%{version}/%{name}-%{version}.tar.gz
Patch0:         106.patch
BuildRequires:  meson >= 0.62.0
BuildRequires:  pesign-obs-integration
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gnu-efi) >= 3.0.18
BuildRequires:  python3-pefile
ExclusiveArch:  x86_64 aarch64 %{arm} %{ix86} riscv64

%description
A UEFI binary for the fwupd project for installing updates using the UpdateCapsule
runtime service.

It was originally imported from the combined fwupd project, and is now
maintained separately to allow fwupd userspace releases and fwupd-efi UEFI
executable releases to follow a different cadence.

%prep
%autosetup -p1

%build
# Dell support requires direct SMBIOS access,
# Synaptics requires Dell support, i.e. x86 only
%meson \
  -Defi_sbat_distro_id="%{sbat_distro}" \
  -Defi_sbat_distro_summary="%{sbat_distro_summary}" \
  -Defi_sbat_distro_pkgname="%{name}" \
  -Defi_sbat_distro_version="%{version}" \
  -Defi_sbat_distro_url="%{sbat_distro_url}" \
  -Dgenpeimg=disabled \
  %{nil}
%meson_build

%install
export BRP_PESIGN_FILES='%{_libexecdir}/fwupd/efi/fwupd*.efi'
%meson_install

# link fwupd*.efi.signed to fwupd*.efi (bsc#1129466)
FWUPD_EFI=`basename %{buildroot}/%{_libexecdir}/fwupd/efi/fwupd*.efi`
ln -s %{_libexecdir}/fwupd/efi/$FWUPD_EFI %{buildroot}/%{_libexecdir}/fwupd/efi/$FWUPD_EFI.signed

# do not need pc file yet
rm $RPM_BUILD_ROOT%{_libdir}/pkgconfig/fwupd-efi.pc

%postun
if [ -e /etc/os-release ]; then
  . /etc/os-release
  efi_distributor="$(echo "${NAME} ${VERSION}" | tr 'A-Z' 'a-z' | cut -d' ' -f1)"
fi
if [ "$1" = 0 ] && [ -d "/boot/efi/EFI/$efi_distributor" ]; then
  # Remove all capsule files
  rm -rf /boot/efi/EFI/"$efi_distributor"/fw
  # Remove the UEFI firmware update program
  rm -f /boot/efi/EFI/"$efi_distributor"/fwupd*.efi
fi

%files

%license COPYING
%doc README.md
%{_libexecdir}/fwupd

%changelog
* Tue Dec 17 2024 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.7:
  * Fix compilation with GNU-EFI 4.0
- Use upstream tarball: source service isn't useful on this
  package
- Add 106.patch:
  * Improves ARM32 crt0 by splitting header and code
  * Use pkgconfig for gnu-efi - fixes RISC-V build
  * Update lds from gnu-efi 4.0
* Thu Aug 29 2024 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.6:
  * Require gnu-efi 3.0.18 or later
  * Ship an objcopy capable LDS for ARM64
  * Detect gnu-efi via pkgconfig
  * Backport the ctors and dtors work from gnu-efi upstream
  * Tidy up crt0 generator
  * Add RISC-V support
  * Fix per NX bit and UEFI 2.10 Microsoft requirements
- Remove un-needed BRs:
  * pkgconfig(efiboot)
  * pkgconfig(efivar)
- Remove shim requirement: it doesn't need it, it's a UEFI binary
- Restore ix86 and ARM32 support
- Add RISC-V support
- Remove patches (fixed upstream):
  * binutils-2.38-arm-objcopy.patch
  * binutils-2.38-arm-system-crt0.patch
  * ARM-fixes.patch
* Fri Feb 24 2023 Callum Farmer <gmbr3@opensuse.org>
- Disable ix86 and arm32: shim doesn't build on these platforms
* Mon Jan 23 2023 Callum Farmer <gmbr3@opensuse.org>
- Update ARM-fixes.patch to current git copy to add checks for
  an incompatible crt0
* Mon Jan  2 2023 Callum Farmer <gmbr3@opensuse.org>
- Add ARM-fixes.patch: multiple fixes for ARM EFI after binutils
  2.38
- Remove arm32-short-wchar.patch: included in ARM-fixes.patch
* Wed Dec 14 2022 Callum Farmer <gmbr3@opensuse.org>
- Add arm32-short-wchar.patch: fix an issue where fwup_sbat.o
  had a different wchar length
* Tue Dec 13 2022 gmbr3@opensuse.org
- Update to version 1.3:
  * Release fwupd-efi 1.3
  * Fix a regression when applying updates on an HP M60
  * Show the version when starting fwupd-efi
  * trivial: Update precommit versions to fix CI
  * meson: fix ARM system crt0 name
  * trivial: post release version bump
- Add binutils-2.38-arm-objcopy.patch: use objcopy with ARM on
  binutils 2.38+
- Add binutils-2.38-arm-system-crt0.patch: system crt0 doesn't need
  to contain the SBAT section if we have binutils 2.38+
- Enable ARM and ix86 support
* Thu Apr 14 2022 Callum Farmer <gmbr3@opensuse.org>
- Use sbat macros (bsc#1193282)
* Fri Mar 11 2022 Frederic Crozat <fcrozat@suse.com>
- Update to version 1.2:
  * Release fwupd-efi 1.2
  * meson: use stadard objcopy binary
  * meson: use find_program() to find the helper scripts we run
  * meson: using local copy ldscript when local copy crt0 be used for SBAT
  * sbat: clarify project URL
  * trivial: Ignore some markdown issues
  * Wait 5 seconds to reboot on errors
  * Port pre-commit clang-format, codespell, markdownlint from fwupd
  * trivial: fixup python errors by codacity/precommit
  * trivial: fixup markdown format
  * trivial: spelling errors
  * Sleep longer when no updates to process
  * README: fix typo and URL
  * trivial: post release version bump
- Remove 0001-meson-using-local-copy-ldscript-when-local-copy-crt0.patch
  (merged upstream)
* Fri Nov  5 2021 Callum Farmer <gmbr3@opensuse.org>
- Re-add fwupdx64.efi.signed symlink (boo#1192206)
* Thu Oct  7 2021 Joey Lee <jlee@suse.com>
- Initial package. fwupd-efi 1.1.
